SyncEngineWithWorker class

Constructors

SyncEngineWithWorker()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required List<RemoteMainHandler> remotes, required StorageMainHandler storage, required List<MainHandlerFactory> plugins, required WorkerSetup workerSetup, required SyncEngineConfig syncEngineConfig, required String jsScript, String? debugName, void onWorkerSpawn()?}) Future<SyncEngine>