BackendWorkerHandlerContext class abstract
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iriFactory → IriTermFactory?
-
no setter
- perflog → Perflog
-
no setterinherited
- rdfCore → RdfCore
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageAccessFactory → BackendStorageAccessFactory
-
no setter
Methods
-
createChannel(
String name) → WorkerHandlerChannel -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited