RemoteMismatchException class

Exception thrown when main and worker handler registrations don't match.

This indicates that a remote handler was registered on one side (main or worker) but is missing on the other side, which would cause runtime failures.

Implemented types

Constructors

RemoteMismatchException(String message, {List<String> missingOnWorker = const [], List<String> missingOnMain = const []})

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
missingOnMain List<String>
final
missingOnWorker List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited