worker_main library

Worker-based architecture for offloading heavy operations to isolate/worker.

Use this API to run SyncEngine in a separate thread, keeping the main thread responsive for UI.

Classes

InMemoryStorageMainHandler
MainHandler
Plugin interface for main-thread components that interact with worker.
MainHandlerChannel
MainHandlerContext
RemoteMainHandler
Main-thread handler for remote backend communication.
StorageMainHandler
Main-thread handler for local storage backend.
SyncEngineWithWorker
WorkerParams

Typedefs

MainHandlerFactory = MainHandler Function(MainHandlerContext workerHandle)
Factory for creating worker plugins with access to the worker handle.
WorkerSetup = Future<WorkerParams> Function()
Factory function type for creating EngineParams in worker.