MainHandlerFactory typedef
MainHandlerFactory =
MainHandler Function(MainHandlerContext workerHandle)
Factory for creating worker plugins with access to the worker handle.
The framework calls this factory after worker creation, passing the handle for communication with the worker thread.
Implementation
typedef MainHandlerFactory = MainHandler Function(
MainHandlerContext workerHandle);