WorkerHandlerChannel class

Properties

channel String
final
hashCode int
The hash code for this object.
no setterinherited
messages Stream<Object?>
Stream of incoming messages on this plugin channel. First listener triggers replay of buffered messages.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(Object? message) → void
Send a message on this plugin channel.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited